package dev.peerat.backend.routes.users;

import java.util.regex.Matcher;

import dev.peerat.backend.bonus.extract.RouteDoc;
import dev.peerat.backend.model.PeerAtUser;
import dev.peerat.backend.model.Player;
import dev.peerat.backend.repository.DatabaseRepository;
import dev.peerat.framework.Context;
import dev.peerat.framework.HttpReader;
import dev.peerat.framework.HttpWriter;
import dev.peerat.framework.RequestType;
import dev.peerat.framework.Response;
import dev.peerat.framework.Route;
import dev.peerat.framework.utils.json.JsonMap;

public class ProfileSettings implements Response{
	
	private DatabaseRepository repo;
	
	public ProfileSettings(DatabaseRepository repo){
		this.repo = repo;
	}

	@RouteDoc(path = "/user/settings", responseCode = 200, responseDescription = "L'utilisateur a mis à jours sont profile")
	@RouteDoc(responseCode = 400, responseDescription = "L'utilisateur a envoyer une donnée unique, déjà utilisée")
	
	@Route(path = "^/user/settings$", type = RequestType.POST, needLogin = true)
	public void exec(Matcher matcher, Context context, HttpReader reader, HttpWriter writer) throws Exception {
		JsonMap json = reader.readJson();
		
		System.out.println("received "+json);
		
		String pseudo = json.get("pseudo");
		String email = json.get("email");
		String firstname = json.get("firstname");
		String lastname = json.get("lastname");
		Player player = repo.getPlayer(context.<PeerAtUser>getUser().getId());
		
		if(!player.getPseudo().equals(pseudo)){
			System.out.println("custom pseudp");
			if(!repo.updatePseudo(context.<PeerAtUser>getUser().getId(), player, pseudo)){
				context.response(400);
				return;
			}
			System.out.println("pseudo changed");
			player.setPseudo(pseudo);
		}
		
		if(!player.getEmail().equals(email)){
			System.out.println("another email");
		}
		
		if((!player.getFirstname().equals(firstname)) || (!player.getLastname().equals(lastname))){
			repo.updateProfile(context.<PeerAtUser>getUser().getId(), player, lastname, firstname);
		}

		System.out.println("200");
		context.response(200);
	}

}
